@@ -25,6 +25,11 @@ class LgIrClimate : public climate_ir::ClimateIR {
       this->swing_mode = climate::CLIMATE_SWING_OFF;
     climate_ir::ClimateIR::control(call);
   }
+  void set_header_high(uint32_t header_high) { this->header_high_ = header_high; }
+  void set_header_low(uint32_t header_low) { this->header_low_ = header_low; }
+  void set_bit_high(uint32_t bit_high) { this->bit_high_ = bit_high; }
+  void set_bit_one_low(uint32_t bit_one_low) { this->bit_one_low_ = bit_one_low; }
+  void set_bit_zero_low(uint32_t bit_zero_low) { this->bit_zero_low_ = bit_zero_low; }
 
  protected:
   /// Transmit via IR the state of this climate controller.
@@ -37,6 +42,12 @@ class LgIrClimate : public climate_ir::ClimateIR {
   void calc_checksum_(uint32_t &value);
   void transmit_(uint32_t value);
 
+  uint32_t header_high_;
+  uint32_t header_low_;
+  uint32_t bit_high_;
+  uint32_t bit_one_low_;
+  uint32_t bit_zero_low_;
+
   climate::ClimateMode mode_before_{climate::CLIMATE_MODE_OFF};
 };
 
