@@ -14,6 +14,7 @@ from esphome.core import coroutine_with_priority
 CODEOWNERS = ["@esphome/core"]
 globals_ns = cg.esphome_ns.namespace("globals")
 GlobalsComponent = globals_ns.class_("GlobalsComponent", cg.Component)
+RestoringGlobalsComponent = globals_ns.class_("RestoringGlobalsComponent", cg.Component)
 GlobalVarSetAction = globals_ns.class_("GlobalVarSetAction", automation.Action)
 
 MULTI_CONF = True
@@ -32,22 +33,25 @@ CONFIG_SCHEMA = cv.Schema(
 async def to_code(config):
     type_ = cg.RawExpression(config[CONF_TYPE])
     template_args = cg.TemplateArguments(type_)
-    res_type = GlobalsComponent.template(template_args)
+    restore = config[CONF_RESTORE_VALUE]
+
+    type = RestoringGlobalsComponent if restore else GlobalsComponent
+    res_type = type.template(template_args)
 
     initial_value = None
     if CONF_INITIAL_VALUE in config:
         initial_value = cg.RawExpression(config[CONF_INITIAL_VALUE])
 
-    rhs = GlobalsComponent.new(template_args, initial_value)
+    rhs = type.new(template_args, initial_value)
     glob = cg.Pvariable(config[CONF_ID], rhs, res_type)
     await cg.register_component(glob, config)
 
-    if config[CONF_RESTORE_VALUE]:
+    if restore:
         value = config[CONF_ID].id
         if isinstance(value, str):
             value = value.encode()
         hash_ = int(hashlib.md5(value).hexdigest()[:8], 16)
-        cg.add(glob.set_restore_value(hash_))
+        cg.add(glob.set_name_hash(hash_))
 
 
 @automation.register_action(
