@@ -4,8 +4,9 @@
 #include "esphome/core/hal.h"
 #include "esphome/components/sensor/sensor.h"
 
-#ifdef USE_ESP32
+#if defined(USE_ESP32) && !defined(USE_ESP32_VARIANT_ESP32C3)
 #include <driver/pcnt.h>
+#define HAS_PCNT
 #endif
 
 namespace esphome {
@@ -17,10 +18,9 @@ enum PulseCounterCountMode {
   PULSE_COUNTER_DECREMENT,
 };
 
-#ifdef USE_ESP32
+#ifdef HAS_PCNT
 using pulse_counter_t = int16_t;
-#endif
-#ifdef USE_ESP8266
+#else
 using pulse_counter_t = int32_t;
 #endif
 
@@ -30,16 +30,15 @@ struct PulseCounterStorage {
 
   static void gpio_intr(PulseCounterStorage *arg);
 
-#ifdef USE_ESP8266
+#ifndef HAS_PCNT
   volatile pulse_counter_t counter{0};
   volatile uint32_t last_pulse{0};
 #endif
 
   InternalGPIOPin *pin;
-#ifdef USE_ESP32
+#ifdef HAS_PCNT
   pcnt_unit_t pcnt_unit;
-#endif
-#ifdef USE_ESP8266
+#else
   ISRInternalGPIOPin isr_pin;
 #endif
   PulseCounterCountMode rising_edge_mode{PULSE_COUNTER_INCREMENT};
@@ -56,6 +55,8 @@ class PulseCounterSensor : public sensor::Sensor, public PollingComponent {
   void set_filter_us(uint32_t filter) { storage_.filter_us = filter; }
   void set_total_sensor(sensor::Sensor *total_sensor) { total_sensor_ = total_sensor; }
 
+  void set_total_pulses(uint32_t pulses);
+
   /// Unit of measurement is "pulses/min".
   void setup() override;
   void update() override;
@@ -65,7 +66,8 @@ class PulseCounterSensor : public sensor::Sensor, public PollingComponent {
  protected:
   InternalGPIOPin *pin_;
   PulseCounterStorage storage_;
-  uint32_t current_total_ = 0;
+  uint32_t last_time_{0};
+  uint32_t current_total_{0};
   sensor::Sensor *total_sensor_;
 };
 
