@@ -9,6 +9,7 @@ from esphome.const import (
     CONF_ESPHOME,
     CONF_USE_ADDRESS,
     CONF_ETHERNET,
+    CONF_WEB_SERVER,
     CONF_WIFI,
     CONF_PORT,
     KEY_CORE,
@@ -20,7 +21,7 @@ from esphome.coroutine import FakeEventLoop as _FakeEventLoop
 
 # pylint: disable=unused-import
 from esphome.coroutine import coroutine, coroutine_with_priority  # noqa
-from esphome.helpers import ensure_unique_string, is_hassio
+from esphome.helpers import ensure_unique_string, is_ha_addon
 from esphome.util import OrderedDict
 
 if TYPE_CHECKING:
@@ -512,7 +513,7 @@ class EsphomeCore:
         if self.config is None:
             raise ValueError("Config has not been loaded yet")
 
-        if "wifi" in self.config:
+        if CONF_WIFI in self.config:
             return self.config[CONF_WIFI][CONF_USE_ADDRESS]
 
         if CONF_ETHERNET in self.config:
@@ -525,9 +526,9 @@ class EsphomeCore:
         if self.config is None:
             raise ValueError("Config has not been loaded yet")
 
-        if "web_server" in self.config:
+        if CONF_WEB_SERVER in self.config:
             try:
-                return self.config["web_server"][CONF_PORT]
+                return self.config[CONF_WEB_SERVER][CONF_PORT]
             except KeyError:
                 return 80
 
@@ -568,12 +569,12 @@ class EsphomeCore:
         return self.relative_build_path("src", *path)
 
     def relative_pioenvs_path(self, *path):
-        if is_hassio():
+        if is_ha_addon():
             return os.path.join("/data", self.name, ".pioenvs", *path)
         return self.relative_build_path(".pioenvs", *path)
 
     def relative_piolibdeps_path(self, *path):
-        if is_hassio():
+        if is_ha_addon():
             return os.path.join("/data", self.name, ".piolibdeps", *path)
         return self.relative_build_path(".piolibdeps", *path)
 
@@ -651,7 +652,7 @@ class EsphomeCore:
                 continue
             if other.repository is not None:
                 if library.repository is None or other.repository == library.repository:
-                    # Other is using a/the same repository, takes precendence
+                    # Other is using a/the same repository, takes precedence
                     break
                 raise ValueError(
                     f"Adding named Library with repository failed! Libraries {library} and {other} "
